# ListLicenseEvaluationContextsResponse

The license evaluation context matching the query 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**license_evaluation_contexts** | [**[LicenseEvaluationContext]**](LicenseEvaluationContext.md) | List of per-org license evaluation context | 
**limit** | **int** | Limit on the number of rows in the response | 
**page_at_id** | **str** | The id to request in the pagination query to get the next page. | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


